@@ -20,6 +20,7 @@ from typing import Tuple
 import humps  # type: ignore
 from aiohttp import ClientConnectorError
 from aiohttp import ClientOSError
+from aiohttp import ClientResponseError
 from aiohttp import ServerDisconnectedError
 from pydantic.dataclasses import dataclass
 from tortoise import fields
@@ -161,16 +162,21 @@ class HasuraGateway(HTTPGateway):
 
     async def _hasura_request(self, endpoint: str, json: Dict[str, Any]) -> Dict[str, Any]:
         self._logger.debug('Sending `%s` request: %s', endpoint, dump_json(json))
-        result = await self.request(
-            method='post',
-            cache=False,
-            url=f'{self._hasura_config.url}/v1/{endpoint}',
-            json=json,
-            headers=self._hasura_config.headers,
-        )
+        try:
+            result = await self.request(
+                method='post',
+                cache=False,
+                url=f'{self._hasura_config.url}/v1/{endpoint}',
+                json=json,
+                headers=self._hasura_config.headers,
+            )
+        except ClientResponseError as e:
+            raise HasuraError(f'{e.status} {e.message}') from e
+
         self._logger.debug('Response: %s', result)
-        if 'error' in result or 'errors' in result:
-            raise HasuraError(result)
+        if errors := result.get('error') or result.get('errors'):
+            raise HasuraError(errors)
+
         return result
 
     async def _healthcheck(self) -> None:
@@ -212,8 +218,11 @@ class HasuraGateway(HTTPGateway):
     async def _replace_metadata(self, metadata: Dict[str, Any]) -> None:
         self._logger.info('Replacing metadata')
         endpoint, json = 'query', {
-            "type": "replace_metadata",
-            "args": metadata,
+            'type': 'replace_metadata',
+            'args': {
+                'metadata': metadata,
+                'allow_inconsistent_metadata': True,
+            },
         }
         await self._hasura_request(endpoint, json)
 
